summaryrefslogtreecommitdiffstats
path: root/src/config.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/config.h')
-rwxr-xr-xsrc/config.h125
1 files changed, 63 insertions, 62 deletions
diff --git a/src/config.h b/src/config.h
index 130ddf9..673150d 100755
--- a/src/config.h
+++ b/src/config.h
@@ -6,10 +6,10 @@
#include "formatinfoloader.h"
#include "conversionoptions.h"
-#include <qobject.h>
-#include <qvaluelist.h>
-#include <qstringlist.h>
-#include <qmap.h>
+#include <tqobject.h>
+#include <tqvaluelist.h>
+#include <tqstringlist.h>
+#include <tqmap.h>
class Logger;
class ConvertPlugin;
@@ -38,19 +38,19 @@ public:
*/
virtual ~FormatItem();
- QStringList mime_types;
- QStringList extensions; // for easy use
- QStringList correction_file_mime_types;
- QStringList correction_file_extensions; // for easy use
- QString description;
+ TQStringList mime_types;
+ TQStringList extensions; // for easy use
+ TQStringList correction_file_mime_types;
+ TQStringList correction_file_extensions; // for easy use
+ TQString description;
FormatInfo::CompressionType compressionType;
int compressionLevel; // the value from the config dialog
bool internalReplayGain;
int size;
- QValueList<ConvertPlugin*> encoders;
- QValueList<ConvertPlugin*> decoders;
- QValueList<ReplayGainPlugin*> replaygains;
- //QValueList<RepairerPlugin*> repairers;
+ TQValueList<ConvertPlugin*> encoders;
+ TQValueList<ConvertPlugin*> decoders;
+ TQValueList<ReplayGainPlugin*> replaygains;
+ //TQValueList<RepairerPlugin*> repairers;
ConvertPlugin* encoder;
ConvertPlugin* decoder;
ReplayGainPlugin* replaygain;
@@ -63,9 +63,10 @@ public:
* @author Daniel Faust <[email protected]>
* @version 0.3
*/
-class Config : public QObject
+class Config : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor
@@ -100,22 +101,22 @@ public:
/**
* Get the encoder for a given file format (mime type or extension)
*/
- ConvertPlugin* encoderForFormat( const QString &format );
+ ConvertPlugin* encoderForFormat( const TQString &format );
/**
* Get the decoder for a given file format (mime type or extension)
*/
- ConvertPlugin* decoderForFormat( const QString &format );
+ ConvertPlugin* decoderForFormat( const TQString &format );
/**
* Get the decoder for a given file format (mime type or extension)
*/
- ReplayGainPlugin* replaygainForFormat( const QString &format );
+ ReplayGainPlugin* replaygainForFormat( const TQString &format );
/**
* Get the format information for a given file format (mime type or extension)
*/
- FormatItem* getFormatItem( const QString &format );
+ FormatItem* getFormatItem( const TQString &format );
/**
* Get the current ripper
@@ -130,119 +131,119 @@ public:
/**
* Returns a list of all loaded rippers
*/
- QValueList<RipperPlugin*> allRippers() { return rippers; }
+ TQValueList<RipperPlugin*> allRippers() { return rippers; }
/**
* Returns a list of all loaded converters
*/
- QValueList<ConvertPlugin*> allConverters() { return converters; }
+ TQValueList<ConvertPlugin*> allConverters() { return converters; }
/**
* Returns a list of all loaded replaygains
*/
- QValueList<ReplayGainPlugin*> allReplayGains() { return replaygains; }
+ TQValueList<ReplayGainPlugin*> allReplayGains() { return replaygains; }
/**
* Returns a list of all known file formats
*/
- QStringList allFormats();
+ TQStringList allFormats();
/**
* Returns a list of all known encodeable file formats
*/
- QStringList allEncodableFormats();
+ TQStringList allEncodableFormats();
/**
* Returns a list of all known lossy encodeable file formats
*/
- QStringList allLossyEncodableFormats();
+ TQStringList allLossyEncodableFormats();
/**
* Returns a list of all known lossless encodeable file formats
*/
- QStringList allLosslessEncodableFormats();
+ TQStringList allLosslessEncodableFormats();
/**
* Returns a list of all known hybrid encodeable file formats
*/
- QStringList allHybridEncodableFormats();
+ TQStringList allHybridEncodableFormats();
/**
* Returns the extension of the correction file format for the given format
* If there is nor correction file format, the returned string is empty
*/
- QString getCorrectionExtension( const QString &format );
+ TQString getCorrectionExtension( const TQString &format );
/**
* Returns a localized description for the given format
*/
- QString getFormatDescription( const QString &format );
+ TQString getFormatDescription( const TQString &format );
/**
* Add a new profile
*/
- void addProfile( const QString &name, const ConversionOptions& profile );
+ void addProfile( const TQString &name, const ConversionOptions& profile );
/**
* Remove a new profile
*/
- void removeProfile( const QString &name );
+ void removeProfile( const TQString &name );
/**
* Returns the conversion options for a profile
*/
- ConversionOptions getProfile( const QString &name );
+ ConversionOptions getProfile( const TQString &name );
/**
* Returns the name of the profile with conversion options @p options
*/
- QString getProfileName( const ConversionOptions& options );
+ TQString getProfileName( const ConversionOptions& options );
/**
* Returns a list of all user defined profiles
*/
- QStringList getAllProfiles();
+ TQStringList getAllProfiles();
/**
* Returns true if the @p file can be added to the conversion list (can be decoded)
*/
- bool acceptFile( const QString& format );
+ bool acceptFile( const TQString& format );
/**
* Returns true if the @p file can be added to the replay gain tool
*/
- bool acceptReplayGainFile( const QString& format );
+ bool acceptReplayGainFile( const TQString& format );
/**
* Returns a file filter suitable for the file open dialog
*/
- QString fileFilter( bool wav = true );
+ TQString fileFilter( bool wav = true );
/**
* Returns a string list of supported file formats
*/
- QStringList fileTypes( bool wav = true );
+ TQStringList fileTypes( bool wav = true );
/**
* Returns a file filter suitable for the file open dialog for the replay gain scanner
*/
- QString replayGainFilter();
+ TQString replayGainFilter();
/**
* Returns a string list of Replay Gain supported file formats
*/
- QStringList replayGainFileTypes();
+ TQStringList replayGainFileTypes();
struct Data {
struct General {
int startTab;
int lastTab;
- QString defaultProfile;
- QString defaultFormat;
-// QString defaultOutputDirectory;
- QString specifyOutputDirectory;
- QString metaDataOutputDirectory;
- QString copyStructureOutputDirectory;
+ TQString defaultProfile;
+ TQString defaultFormat;
+// TQString defaultOutputDirectory;
+ TQString specifyOutputDirectory;
+ TQString metaDataOutputDirectory;
+ TQString copyStructureOutputDirectory;
int priority;
bool useVFATNames;
int conflictHandling;
@@ -256,8 +257,8 @@ public:
bool checkForUpdates;
} plugins;
struct Environment {
- QStringList directories;
- QStringList foundPrograms;
+ TQStringList directories;
+ TQStringList foundPrograms;
} environment;
struct App {
int configVersion;
@@ -267,36 +268,36 @@ public:
bool onlinePluginsChanged;
bool backendsChanged;
- QMap<QString, QString> binaries;
+ TQMap<TQString, TQString> binaries;
private:
struct PluginMapData {
int version;
- QString filename;
- QString type;
+ TQString filename;
+ TQString type;
};
Logger* logger;
/** holds all known formats */
- QValueList<FormatItem> formats;
+ TQValueList<FormatItem> formats;
/** holds all known rippers */
- QValueList<RipperPlugin*> rippers;
+ TQValueList<RipperPlugin*> rippers;
RipperPlugin* currentRipper;
/** holds all known converters */
- QValueList<ConvertPlugin*> converters;
+ TQValueList<ConvertPlugin*> converters;
/** holds all known replaygain apps */
- QValueList<ReplayGainPlugin*> replaygains;
+ TQValueList<ReplayGainPlugin*> replaygains;
/* holds all known file repairing apps */
-// QValueList<RepairerItem> repairer;
+// TQValueList<RepairerItem> repairer;
//ConvertPluginLoader* convertPluginLoader;
//ReplayGainPluginLoader* replaygainPluginLoader;
/** holds all user defined profiles */
- QValueList<ProfileData> profiles;
+ TQValueList<ProfileData> profiles;
/**
* Load the files with the file infos (format descriptions, file size, etc.)
@@ -314,10 +315,10 @@ private:
* @p extension The file name extension for that is wants to register
* @p features The features of the app for that extension
*/
- void registerFormatFeatures( const QString &mime_type,
+ void registerFormatFeatures( const TQString &mime_type,
ConvertPlugin* encoder = 0, ConvertPlugin* decoder = 0,
ReplayGainPlugin* replaygain = 0/*, RepairPlugin* repairer = 0*/,
- const QString &correction_file_mime_type = QString::null );
+ const TQString &correction_file_mime_type = TQString() );
/**
* Generate the service menu
@@ -337,11 +338,11 @@ private:
* @p newDescription Register a new description for this file format?
* @p newSize Register a new size for this file format for calculating the progress?
*/
- /*void registerFileFormat( const QString &extension, const QString &newSynonym = QString::null,
- const QString &newMimeType = QString::null,
- const QString &newDescription = QString::null,
+ /*void registerFileFormat( const TQString &extension, const TQString &newSynonym = TQString(),
+ const TQString &newMimeType = TQString(),
+ const TQString &newDescription = TQString(),
int newSize = 0, FormatInfo::CompressionType newCompressionType = FormatInfo::lossy );*/
- //void registerFileFormat( const QString &mime_type, const QString &option, const QString &value );
+ //void registerFileFormat( const TQString &mime_type, const TQString &option, const TQString &value );
// NOTE this function is obsolete.
// after loading all plugins and creating all neccessary file format items,
// sk will search for format info files and update the items.